@@ -12,7 +12,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-01-19'; # DATE
 our $DIST = 'Complete-Sah'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %SPEC;
 our @EXPORT_OK = qw(complete_from_schema);
@@ -53,6 +53,7 @@ _
             req => 1,
         },
     },
+    result_naked => 1,
 };
 sub complete_from_schema {
     my %args = @_;
@@ -363,7 +364,7 @@ Complete::Sah - Sah-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.009 of Complete::Sah (from Perl distribution Complete-Sah), released on 2023-01-19.
+This document describes version 0.010 of Complete::Sah (from Perl distribution Complete-Sah), released on 2023-01-19.
 
 =head1 SYNOPSIS
 
@@ -378,7 +379,7 @@ This document describes version 0.009 of Complete::Sah (from Perl distribution C
 
 Usage:
 
- complete_from_schema(%args) -> [$status_code, $reason, $payload, \%result_meta]
+ complete_from_schema(%args) -> any
 
 Complete a value from schema.
 
@@ -409,15 +410,6 @@ case schema must already be normalized.
 
 =back
 
-Returns an enveloped result (an array).
-
-First element ($status_code) is an integer containing HTTP-like status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-($reason) is a string containing error message, or something like "OK" if status is
-200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
-element (%result_meta) is called result metadata and is optional, a hash
-that contains extra information, much like how HTTP response headers provide additional metadata.
-
 Return value:  (any)
 
 =head1 HOMEPAGE
